package com.happy.Model;

import java.util.List;

/**
 * @Description  
 * @Author  raojiaolong
 * @String 2023-07-29 
 */

public class House {


	/**
	 * id
	 */
	private String id;

	/**
	 * 所属商家Id
	 */
	private String managerId;

	/**
	 * 房型名称
	 */
	private String hName;

	/**
	 * 房型面积
	 */
	private String hAreas;

	/**
	 * 单价
	 */
	private Double price;

	/**
	 * 数量
	 */
	private Integer number;

	/**
	 * 房型配置
	 */
	private String hConfig;

	private  List hConfigList;
	/**
	 * 备注
	 */
	private String remark;

	private String remainRooms;

	/**
	 * 创建人
	 */
	private Integer createId;

	/**
	 * 创建时间
	 */
	private String createDate;

	/**
	 * 修改时间
	 */
	private String modifyDate;

	/**
	 * 数据状态
	 */
	private Integer status;

	/**
	 * 房型详细图
	 */
	private List<FileInfo> fileInfoList;

	/**
	 * 房间号
	 */
	private List<HouseNumber> houseNumbers;

	public List<HouseNumber> getHouseNumbers() {
		return houseNumbers;
	}

	public void setHouseNumbers(List<HouseNumber> houseNumbers) {
		this.houseNumbers = houseNumbers;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getManagerId() {
		return managerId;
	}

	public void setManagerId(String managerId) {
		this.managerId = managerId;
	}

	public String gethName() {
		return hName;
	}

	public void sethName(String hName) {
		this.hName = hName;
	}

	public String gethAreas() {
		return hAreas;
	}

	public void sethAreas(String hAreas) {
		this.hAreas = hAreas;
	}

	public Double getPrice() {
		return price;
	}

	public void setPrice(Double price) {
		this.price = price;
	}

	public Integer getNumber() {
		return number;
	}

	public void setNumber(Integer number) {
		this.number = number;
	}

	public String gethConfig() {
		return hConfig;
	}

	public void sethConfig(String hConfig) {
		this.hConfig = hConfig;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public Integer getCreateId() {
		return createId;
	}

	public void setCreateId(Integer createId) {
		this.createId = createId;
	}

	public String getCreateDate() {
		return createDate;
	}

	public void setCreateDate(String createDate) {
		this.createDate = createDate;
	}

	public String getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(String modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Integer getStatus() {
		return status;
	}

	public void setStatus(Integer status) {
		this.status = status;
	}

	public List<FileInfo> getFileInfoList() {
		return fileInfoList;
	}

	public void setFileInfoList(List<FileInfo> fileInfoList) {
		this.fileInfoList = fileInfoList;
	}

	public String getRemainRooms() {
		return remainRooms;
	}

	public void setRemainRooms(String remainRooms) {
		this.remainRooms = remainRooms;
	}

	public List gethConfigList() {
		return hConfigList;
	}

	public void sethConfigList(List hConfigList) {
		this.hConfigList = hConfigList;
	}
}
